==> apache-brooklyn-0.9.0-rc2-src.zip: apache-brooklyn-0.9.0-src/brooklyn-server/test-support/src/main/java/org/apache/brooklyn/test/performance/PerformanceTestResult.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.brooklyn.test.performance;

import java.util.List;

import org.apache.brooklyn.util.time.Duration;

import com.google.common.annotations.Beta;
import com.google.common.base.Objects;

/**
 * The results of a performance test.
 * 
 * See {@link PerformanceTestUtils#run(MeasurementOptions)}.
 */
@Beta
public class PerformanceTestResult {
    public String summary;
    public Duration warmup;
    public int warmupIterations;
    public Duration duration;
    public int iterations;
    public double ratePerSecond;
    public Histogram histogram;
    public Double minAcceptablePerSecond;
    public Double cpuTotalFraction;
    public List<Double> cpuSampleFractions;
    
    @Override
    public String toString() {
        return Objects.toStringHelper(this)
                .omitNullValues()
                .add("summary", summary)
                .add("duration", duration)
                .add("warmup", warmup)
                .add("iterations", iterations)
                .add("warmupIterations", warmupIterations)
                .add("ratePerSecond", ratePerSecond)
                .add("histogram", histogram)
                .add("cpuTotalFraction", cpuTotalFraction)
                .add("cpuSampleFractions", cpuSampleFractions)
                .add("minAcceptablePerSecond", minAcceptablePerSecond)
                .toString();
    }
}

==> apache-brooklyn-1.1.0-src.zip: apache-brooklyn-1.1.0-src/brooklyn-server/test-support/src/main/java/org/apache/brooklyn/test/performance/PerformanceTestResult.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.brooklyn.test.performance;

import java.util.List;

import org.apache.brooklyn.util.time.Duration;

import com.google.common.annotations.Beta;
import com.google.common.base.MoreObjects;

/**
 * The results of a performance test.
 * 
 * See {@link PerformanceTestUtils#run(MeasurementOptions)}.
 */
@Beta
public class PerformanceTestResult {
    public String summary;
    public Duration warmup;
    public int warmupIterations;
    public Duration duration;
    public int iterations;
    public double ratePerSecond;
    public Histogram histogram;
    public Double minAcceptablePerSecond;
    public Double cpuTotalFraction;
    public List<Double> cpuSampleFractions;
    
    @Override
    public String toString() {
        return MoreObjects.toStringHelper(this)
                .omitNullValues()
                .add("summary", summary)
                .add("duration", duration)
                .add("warmup", warmup)
                .add("iterations", iterations)
                .add("warmupIterations", warmupIterations)
                .add("ratePerSecond", ratePerSecond)
                .add("histogram", histogram)
                .add("cpuTotalFraction", cpuTotalFraction)
                .add("cpuSampleFractions", cpuSampleFractions)
                .add("minAcceptablePerSecond", minAcceptablePerSecond)
                .toString();
    }
}
